import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.util.HashMap;

/**
 * Bullet that destroys enemies
 * 
 * @author Michael Garwood
 * @version 3/1/10
 */
public class Bullet  extends Actor
{

    private int x;
    private int y;
    private boolean isAlive = true;
    private HashMap<Integer, Integer> directions = new HashMap<Integer, Integer>();
    
    
    /**
     * Act - do whatever the Bullet wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        move(x, y);
        harmEnemy();
        if(isAlive)
        {            
            removeAtEdge();
        }
    }    
    
    public Bullet(int thisRotation)
    {   
        directions.put(0, 0);
        directions.put(1, -20);
        directions.put(45, 13);
        directions.put(46, -13);
        directions.put(90, 20);
        directions.put(91, 0);
        directions.put(135, 13);
        directions.put(136, 13);
        directions.put(180, 0);
        directions.put(181, 20);
        directions.put(225, -13);
        directions.put(226, 13);
        directions.put(270, -20);
        directions.put(271, 0);
        directions.put(315, -13);
        directions.put(316, -13);
        
        x = directions.get(thisRotation);
        y = directions.get(thisRotation + 1);
        setRotation(thisRotation);
    }
    
    /**
     * Moves the bullet forwards in a straight line
     * @param movementX Movement in the x direction
     * @param movementY Movement in the y direction
     */
    public void move(int movementX, int movementY)
    {
        setLocation(getX() + movementX, getY() + movementY);
    }
    
    /**
     * Removes itself if the bullet hits the edge of the world
     */
    public void removeAtEdge()
    {
        if(getX() == 0 || getX() == 499 || getY() == 0 || getY() == 499)
        {
            end();
        }
    }
    
    public void harmEnemy()
    {
        Actor enemy = getOneIntersectingObject(Enemy.class);
        if(enemy != null)
        {
            ((Enemy) enemy).hit();
            end();
        }
    }
            
    
    /**
     * Bullet destroys itself
     */
    public void end()
    {
        getWorld().removeObject(this);
        isAlive = false;
    }
}
    