import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.util.ArrayList;

/**
 * Player controlled ship that is able to shoot projectiles to attack enemies
 * Also able to die and has lives
 * 
 * @author Michael Garwood
 * @version 3/1/10
 */
public class Player  extends Actor
{

    private int shootCounter = 0;
    private int shootLimit = 10;
    private int health = 3;
    private int imageChangeCounter = 15;
    private int flashCounter = 0;
    private boolean transImage = true;
    private boolean canHarm = true;
    private ArrayList<String> keyList = new ArrayList<String>();
    
    
    public Player()
    {
        keyList.add("up");
        keyList.add("down");
        keyList.add("left");
        keyList.add("right");
    }

    /**
     * Act - do whatever the Player wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        checkKeys();
        invincible();
        endGame();
    }    
    
    /**
     * Returns the player's lives
     */
    public int returnLives()
    {
        return health;
    }
    
    /**
     * Checks if any relevant keys are pressed and calls methods for controls
     */
    public void checkKeys()
    {
        
        if(Greenfoot.isKeyDown("up") && multipleKeyCheck("up"))
        {
            move(0, -5);
            setRotation(0);
        }
        
        if(Greenfoot.isKeyDown("down") && multipleKeyCheck("down"))
        {
            move(0, 5);
            setRotation(180);
        }
        
        if(Greenfoot.isKeyDown("left") && multipleKeyCheck("left"))
        {
            move(-5, 0);
            setRotation(270);
        }
        
        if(Greenfoot.isKeyDown("right") && multipleKeyCheck("right"))
        {
            move(5, 0);
            setRotation(90);
        }
        
        if(Greenfoot.isKeyDown("up") && Greenfoot.isKeyDown("right"))
        {
            move(3, -3);
            setRotation(45);
        }
        
        if(Greenfoot.isKeyDown("down") && Greenfoot.isKeyDown("right"))
        {
            move(3, 3);
            setRotation(135);
        }
        
        if(Greenfoot.isKeyDown("down") && Greenfoot.isKeyDown("left"))
        {
            move(-3, 3);
            setRotation(225);
        }

        if(Greenfoot.isKeyDown("up") && Greenfoot.isKeyDown("left"))
        {
            move(-3, -3);
            setRotation(315);
        }
        
        if(Greenfoot.isKeyDown("space"))
        {
            shoot();
        }
        
    }
    
    /**
     * Returns true only if one key is pressed
     * @param correctKey The key to make sure is only being pressed
     */
    public boolean multipleKeyCheck(String correctKey)
    {
        for(String key : keyList)
        {
            if(Greenfoot.isKeyDown(key) && key != correctKey)
            {
                return false;
            }
        }
        return true;
    }
    
    
    /**
     * Moves the player across the game field
     * @param x Change in x direction
     * @param y Chance in y direction
     */
    public void move(int x, int y)
    {
        setLocation(getX() + x, getY() + y);
    }
    
    /**
     * Shoot a bullet into the field
     */
    public void shoot()
    {
        if(shootCounter == 0)
        {
            int rotationX = (getRotation() == 90 || getRotation() == 270)?0:((getRotation() == 0 || getRotation() == 45)?10:-10);
            int rotationY = (getRotation() == 225)?-10:((getRotation() == 45 || getRotation() == 90 || getRotation() == 135 || getRotation() == 270 || getRotation() == 315)?10:0);
            
            
            getWorld().addObject(new Bullet(getRotation()), getX(), getY());
            getWorld().addObject(new Bullet(getRotation()), getX() + rotationX, getY() + rotationY);
            getWorld().addObject(new Bullet(getRotation()), getX() - rotationX, getY() - rotationY);
            shootCounter = shootLimit;
        }
        else
        {
            shootCounter--;
        }
    }
    
    /**
     * Removes one life from the player and returns them to the center of the screen
     */
    public void harm()
    {
        if(canHarm)
        {
            health--;
            Greenfoot.delay(50);
            setLocation(250, 250);
            canHarm = false;
        }
    }
    
    public void invincible()
    {
        if(!canHarm && flashCounter <= 120)
        {
            if(flashCounter == imageChangeCounter)
            {
                setImage(((transImage == true)?"invis.png":"Player.png"));
                transImage = ((transImage == true)?false:true);
                imageChangeCounter += 15;
            }
            flashCounter++;
        }
        else
        {
            transImage = true;
            canHarm = true;
            flashCounter = 0;
            imageChangeCounter = 15;
        }
    }
    
    public void endGame()
    {
        if(health == -1)
        {
            ((VectorWorld) getWorld()).gameOver();
            health = 3;
        }
    }
}