import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Small display of how many points the player has scored by killing an enemy
 * when they are destroyed
 * 
 * @author Michael "Squirrels" Garwood
 * @version 14/1/10
 */
public class ScoreBlip  extends Actor
{
    
    //A lower amount means it will scroll faster
    private int scrollSpeed = 1;
    private int scrollTick = 0;
    //A lower rate means it will disappear slower
    private int transRate = 5;

    public ScoreBlip(String scoreAmount)
    {
        setImage(scoreAmount + ".png");
    }
    /**
     * Act - do whatever the ScoreBlip wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        scroll();
        disappear();
        remove();
    }
    
    /**
     * Scrolls the image upwards
     */
    public void scroll()
    {
        if(scrollTick == 0)
        {
            setLocation(getX(), getY() - 1);
            scrollTick = scrollSpeed;
        }
        else
        {
            scrollTick--;
        }
    }
    
    /**
     * Gradually makes the image disappear
     */
    public void disappear()
    {
        if(getImage().getTransparency() - transRate >= 0)
        {
            getImage().setTransparency(getImage().getTransparency() - transRate);
        }
        else
        {
            getImage().setTransparency(0);
        }
    }
    
    /**
     * Removes the object from the world when it has become completely invisible
     */
    public void remove()
    {
        if(getImage().getTransparency() <= 0)
        {
            getWorld().removeObject(this);
        }
    }
}
