import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Groups of these enemies follow the player constantly, but at a lower speed
 * than the player
 * 
 * @author Michael "Squirrels" Garwood
 * @version 13/1/10
 */
public class Swarmer  extends Enemy
{
    
    private boolean burst = true;
    private boolean canDie = false;
    private boolean createSwarmlets = true;
    private int burstCountdown = 0;
    private int velocity = 2;
    private int swarmerHealth = 6;

    /**
     * Creates a swarmer enemy
     * @param thisSquadNum Used by the starting burst method to decide what angle to 
     * initially travel towards (0-6)
     * @param x starting X coordinate
     * @param y starting Y coordinate
     */
    public Swarmer()
    {
        super(1, 20);
    }
    /**
     * Act - do whatever the Swarmer wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        createSwarmlets();
        collide();
        burst();
        travel();
        swarmerDie();
    }    
    
    /**
     * Travels towards the player
     * 
     * Original idea by Steve West
     */
    public void travel()
    {
        if(!burst)
        {
            
            int playerX = ((VectorWorld) getWorld()).getPlayerX();
            int playerY = ((VectorWorld) getWorld()).getPlayerY();
            
            if(playerX > getX())
            {
                move(2, 0);
            }
            else if(playerX < getX())
            {
                move(-2, 0);
            }
            
            if(playerY > getY())
            {
                move(0, 2);
            }
            else if(playerY < getY())
            {
                move(0, -2);
            }

            
        }
    }
    
    /**
     * Waits for the other Swarmlets to get into formation
     */
    public void burst()
    {
        if(burst && burstCountdown != 10)
        {
            burstCountdown++;
        }
        else
        {
            burst = false;
        }
    }
    
    /**
     * Returns Swarmer's X position
     */
    public int returnX()
    {
        return getX();
    }
    
    /**
     * Returns Swarmer's Y position
     */
    public int returnY()
    {
        return getY();
    }
    
    /**
     * Makes sure that the swarmer will only die if every
     * swarmlet has been destroyed
     */
    public void swarmerDie()
    {
        if(swarmerHealth <= 0 && !canDie)
        {
            health = 1;
            canDie = true;
        }
        
        if(canDie)
        {
            die();
        }
    }
    
    /**
     * Removes one of the Swarmer's "swarmer health" points
     */
    public void swarmletHit()
    {
        swarmerHealth--;
    }
    
    /**
     * Creates 6 swarmlets
     */
    public void createSwarmlets()
    {
        if(createSwarmlets)
        {
            for(int i = 1; i <= 6; i++)
            {
                getWorld().addObject(new Swarmlet(i, this), getX(), getY());
            }
            createSwarmlets = false;
        }
    }
        
        
}
