import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Enemy that attempts to fly towards the enemy. Keep moving to avoid it!
 * 
 * @author Michael "Squirrels" Garwood
 * @version 11/1/10
 */
public class Tracker  extends Enemy
{

    private boolean track = false;
    private boolean travel = false;
    private int xDestination;
    private int yDestination;
    private int defaultAcc = 17;
    private int acceleration = defaultAcc;
    private int moveCounter = 50;
    private int step = 0;
    private int halfDistance;

    public Tracker()
    {
        super(1, 100);
    }
    
    
    /**
     * Act - do whatever the Tracker wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        collide();
        track();
        approach();
        delay();
        die();
    }    
    
    /**
     * Gets the player's location and then initiates travelling to it
     */
    public void track()
    {
        if(track)
        {
            xDestination = ((VectorWorld) getWorld()).getPlayerX();
            yDestination = ((VectorWorld) getWorld()).getPlayerY();
            double halfDistanceFloat = Math.sqrt(xDestination^2 + yDestination^2) / 2;
            halfDistance = (int) halfDistanceFloat;
            
            track = false;
            travel = true;
            
            rotate();
        }
    }
    
    /**
     * Approaches the player
     */
    public void approach()
    {
        if(travel)
        {   
            move(((xDestination - getX())/acceleration), ((yDestination - getY())/acceleration));
            if((Math.sqrt(xDestination^2 + yDestination^2)) >= halfDistance && acceleration < defaultAcc)
            {
                acceleration++;
            }
            else
            {
                acceleration--;
            }
            step++;
        }
        
        if(step == 150)
        {
            travel = false;
            acceleration = defaultAcc;
            step = 0;
        }
    }
    
    /**
     * Leaves a small delay for the player to move
     */
    public void delay()
    {
        if(travel == false && track == false)
        {
            if(moveCounter == 0)
            {
                track = true;
                moveCounter = 50;
            }
            else
            {
                moveCounter--;
            }
        }   
    }
    
    /**
     * Rotates the ship to face the player
     */
    public void rotate()
    {
        double xTrig = xDestination - getX();
        double yTrig = yDestination - getY();
        double doubleAngle = Math.toDegrees(Math.atan((yTrig/xTrig)));
        int angle = (int) doubleAngle;
        
        if(xTrig >= 0 && yTrig >= 0)
        {
            setRotation(90 + angle);
        }
        if(xTrig < 0 && yTrig >= 0)
        {
            setRotation(270 + angle);
        }
        if(xTrig < 0 && yTrig < 0)
        {
            setRotation(270 + angle);
        }
        if(xTrig >= 0 && yTrig < 0)
        {
            setRotation(90 + angle);
        }
    }
        
}
